@@ -1,8 +1,9 @@
 package Padre::DB;
 
 # Provide an ORLite-based API for the Padre database
-
+use 5.008;
 use strict;
+use warnings;
 use File::Spec      ();
 use File::ShareDir  ();
 use Params::Util    ();
@@ -33,7 +34,7 @@ use Padre::DB::LastPositionInFile ();
 use Padre::DB::Session            ();
 use Padre::DB::SessionFile        ();
 
-our $VERSION    = '0.43';
+our $VERSION    = '0.44';
 our $COMPATIBLE = '0.26';
 
 
