@@ -11,7 +11,7 @@ use Padre::Document ();
 use Padre::Util     ();
 use Padre::Perl     ();
 
-our $VERSION = '0.43';
+our $VERSION = '0.44';
 our @ISA     = 'Padre::Document';
 
 #####################################################################
@@ -108,11 +108,11 @@ sub set_highlighter {
 	# configuration variable
 	my $limit;
 	if ( $module eq 'Padre::Document::Perl::PPILexer' ) {
-		$limit = 2000;
+		$limit = 4000;
 	} elsif ( $module eq 'Padre::Document::Perl::Lexer' ) {
-		$limit = 2000;
+		$limit = 4000;
 	} elsif ( $module eq 'Padre::Plugin::Kate' ) {
-		$limit = 2000;
+		$limit = 4000;
 	}
 
 	my $length = $self->{original_content} ? length $self->{original_content} : 0;
@@ -610,7 +610,7 @@ sub autocomplete {
 	my $post_text = $editor->GetTextRange( $first, $last );
 
 	my $regex;
-	eval { $regex = qr{\b($prefix\w+(?:::\w+)*)\b} };
+	eval { $regex = qr{\b(\Q$prefix\E\w+(?:::\w+)*)\b} };
 	if ($@) {
 		return ("Cannot build regex for '$prefix'");
 	}
@@ -838,145 +838,19 @@ sub event_on_left_up {
 }
 
 #
-# Render Perl 5 help xhtml for Padre's Help Search facility
+# Returns Perl's Help Provider
 #
-sub on_help_render {
-	my ( $self, $topic ) = @_;
-
-	require Padre::DocBrowser::POD;
-	use Pod::Functions;
-	$Type{say}   = 1;
-	$Type{state} = 1;
-	$Type{break} = 1;
-
-	my $hints = ();
-
-	if ( $topic =~ /^(\$|\@|\%)/ ) {
-		$hints->{perlvar} = 1;
-	} elsif ( $Type{$topic} ) {
-		$hints->{perlfunc} = 1;
-	}
-
-	# handle topics like q/.../, m//, y///, tr///
-	$topic =~ s/\/.*$//;
-
-	my $pod = Padre::DocBrowser::POD->new;
-	my $doc = $pod->resolve( $topic, $hints );
-
-	my $html = $pod->render($doc);
-	return ( $html->body, $topic );
+sub get_help_provider {
+	require Padre::HelpProvider::Perl;
+	return Padre::HelpProvider::Perl->new;
 }
 
 #
-# Render Perl 5 help list for Padre's Help Search facility
+# Returns Perl's Quick Fix Provider
 #
-sub on_help_list {
-
-	my @index = ();
-
-	# The categorization has been "borrowed" from
-	# http://github.com/jonallen/perldoc.perl.org/tree
-	# In lib/PerlDoc/Section.pm
-
-	# Overview
-	push @index, qw/perl perlintro perlrun perlbook perlcommunity/;
-
-	# Tutorials
-	push @index, qw/perlreftut perldsc perllol perlrequick
-		perlretut perlboot perltoot perltooc perlbot
-		perlstyle perlcheat perltrap perldebtut
-		perlopentut perlpacktut perlthrtut perlothrtut
-		perlxstut perlunitut perlpragma/;
-
-	# FAQ
-	push @index, qw/perlunifaq perlfaq1 perlfaq2 perlfaq3
-		perlfaq4 perlfaq5 perlfaq6 perlfaq7 perlfaq8 perlfaq9/;
-
-	# Language reference
-	push @index, qw/perlsyn perldata perlsub perlop
-		perlfunc perlpod perlpodspec perldiag
-		perllexwarn perldebug perlvar perlre
-		perlreref perlref perlform perlobj perltie
-		perldbmfilter perlipc perlfork perlnumber
-		perlport perllocale perluniintro perlunicode
-		perlebcdic perlsec perlmod perlmodlib
-		perlmodstyle perlmodinstall perlnewmod
-		perlcompile perlfilter perlglossary CORE/;
-
-	# Internals
-	push @index, qw/perlembed perldebguts perlxs perlxstut
-		perlclib perlguts perlcall perlapi perlintern
-		perliol perlapio perlhack perlreguts perlreapi/;
-
-	# History
-	push @index, qw/perlhist perltodo perldelta/;
-
-	# license
-	push @index, qw/perlartistic perlgpl/;
-
-	# Platform Specific
-	push @index, qw/perlaix perlamiga perlapollo perlbeos perlbs2000
-		perlce perlcygwin perldgux perldos perlepoc
-		perlfreebsd perlhpux perlhurd perlirix perllinux
-		perlmachten perlmacos perlmacosx perlmint perlmpeix
-		perlnetware perlos2 perlos390 perlos400
-		perlplan9 perlqnx perlsolaris perlsymbian perltru64 perluts
-		perlvmesa perlvms perlvos perlwin32/;
-
-	# Pragmas
-	push @index, qw/attributes attrs autouse base bigint bignum
-		bigrat blib bytes charnames constant diagnostics
-		encoding feature fields filetest if integer less lib
-		locale mro open ops overload re sigtrap sort strict
-		subs threads threads::shared utf8 vars vmsish
-		warnings warnings::register/;
-
-	# Utilities
-	push @index, qw/perlutil a2p c2ph config_data corelist cpan cpanp
-		cpan2dist dprofpp enc2xs find2perl h2ph h2xs instmodsh
-		libnetcfg perlbug perlcc piconv prove psed podchecker
-		perldoc perlivp pod2html pod2latex pod2man pod2text
-		pod2usage podselect pstruct ptar ptardiff s2p shasum
-		splain xsubpp perlthanks/;
-
-	# Perl Special Variables (compiled these from perlvar)
-	push @index,
-		(
-		'$ARG', '$_',            '$a',                '$b', '$<*digits*>',           '$MATCH',
-		'$&',   '${^MATCH}',     '$PREMATCH',         '$`', '${^PREMATCH}',          '$POSTMATCH',
-		'$\'',  '${^POSTMATCH}', '$LAST_PAREN_MATCH', '$+', '$LAST_SUBMATCH_RESULT', '$^N',
-		'@LAST_MATCH_END',         '@+',  '%+', '$INPUT_LINE_NUMBER', '$NR', '$.',
-		'$INPUT_RECORD_SEPARATOR', '$RS', '$/', '$OUTPUT_AUTOFLUSH',  '$|',  '$OUTPUT_FIELD_SEPARATOR',
-		'$OFS', '$,',                   '$OUTPUT_RECORD_SEPARATOR', '$ORS', '$\\',                 '$LIST_SEPARATOR',
-		'$"',   '$SUBSCRIPT_SEPARATOR', '$SUBSEP',                  '$;',   '$FORMAT_PAGE_NUMBER', '$%',
-		'$FORMAT_LINES_PER_PAGE', '$=', '$FORMAT_LINES_LEFT', '$-', '@LAST_MATCH_START', '@-',
-		'%-', '$FORMAT_NAME',           '$~',           '$FORMAT_TOP_NAME', '$^',     '$FORMAT_LINE_BREAK_CHARACTERS',
-		'$:', '$FORMAT_FORMFEED',       '$^L',          '$ACCUMULATOR',     '$^A',    '$CHILD_ERROR',
-		'$?', '${^CHILD_ERROR_NATIVE}', '${^ENCODING}', '$OS_ERROR',        '$ERRNO', '$!',
-		'%OS_ERROR', '%ERRNO',              '%!',         '$EXTENDED_OS_ERROR', '$^E',            '$EVAL_ERROR',
-		'$@',        '$PROCESS_ID',         '$PID',       '$$',                 '$REAL_USER_ID',  '$UID',
-		'$<',        '$EFFECTIVE_USER_ID',  '$EUID',      '$>',                 '$REAL_GROUP_ID', '$GID',
-		'$(',        '$EFFECTIVE_GROUP_ID', '$EGID',      '$)',                 '$PROGRAM_NAME',  '$0',
-		'$[',        '$]',                  '$COMPILING', '$^C',                '$DEBUGGING',     '$^D',
-		'${^RE_DEBUG_FLAGS}', '${^RE_TRIE_MAXBUF}', '$SYSTEM_FD_MAX', '$^F',     '$^H', '%^H',
-		'$INPLACE_EDIT',      '$^I',                '$^M',            '$OSNAME', '$^O', '${^OPEN}',
-		'$PERLDB',   '$^P', '$LAST_REGEXP_CODE_RESULT', '$^R',         '$EXCEPTIONS_BEING_CAUGHT', '$^S',
-		'$BASETIME', '$^T', '${^TAINT}',                '${^UNICODE}', '${^UTF8CACHE}',            '${^UTF8LOCALE}',
-		'$PERL_VERSION',    '$^V',  '$WARNING', '$^W',   '${^WARNING_BITS}', '${^WIN32_SLOPPY_STAT}',
-		'$EXECUTABLE_NAME', '$^X',  'ARGV',     '$ARGV', '@ARGV',            'ARGVOUT',
-		'@F',               '@INC', '@ARG',     '@_',    '%INC',             '%ENV',
-		'$ENV{expr}',       '%SIG', '$SIG{expr}'
-		);
-
-	# Add Perl functions (perlfunc)
-	use Pod::Functions;
-	push @index, keys %Type;
-
-	# Add CORE modules
-	require Module::CoreList;
-	push @index, Module::CoreList->find_modules( qr//, $] );
-
-	return sort @index;
+sub get_quick_fix_provider {
+	require Padre::QuickFixProvider::Perl;
+	return Padre::QuickFixProvider::Perl->new;
 }
 
 1;
